# Release History

## 12.0.0b2 (2026-07-07)

### Features Added

  - Client `EventHubManagementClient` added parameter `cloud_setting` in method `__init__`
  - Client `EventHubManagementClient` added method `send_request`
  - Model `Destination` added property `identity`
  - Model `NetworkSecurityPerimeterConfiguration` added property `system_data`
  - Model `ProxyResource` added property `system_data`
  - Model `Resource` added property `system_data`
  - Enum `SchemaType` added member `JSON`
  - Enum `SchemaType` added member `PROTO_BUF`
  - Enum `TlsVersion` added member `ONE3`
  - Added model `CaptureIdentity`
  - Added enum `CaptureIdentityType`
  - Added enum `CleanupPolicyRetentionDescription`
  - Added model `ConfidentialCompute`
  - Added model `FailOver`
  - Added model `FailOverProperties`
  - Added enum `GeoDRRoleType`
  - Added model `GeoDataReplicationProperties`
  - Added enum `IpAddressType`
  - Added model `MessageTimestampDescription`
  - Added enum `Mode`
  - Added model `NamespaceReplicaLocation`
  - Added model `PlatformCapabilities`
  - Added enum `ProvisioningState`
  - Added model `RetentionDescription`
  - Added enum `TimestampType`
  - Operation group `NamespacesOperations` added method `begin_failover`
  - Operation group `NetworkSecurityPerimeterConfigurationsOperations` added method `get_resource_association_name`

### Breaking Changes

  - This version introduces new hybrid models which have dual dictionary and model nature. Please follow https://aka.ms/azsdk/python/migrate/hybrid-models for migration.
  - Model `ApplicationGroup` moved instance variable `is_enabled`, `client_app_group_identifier` and `policies` under property `properties` whose type is `ApplicationGroupProperties`
  - Model `ArmDisasterRecovery` moved instance variable `provisioning_state`, `partner_namespace`, `alternate_name`, `role` and `pending_replication_operations_count` under property `properties` whose type is `ArmDisasterRecoveryProperties`
  - Model `AuthorizationRule` moved instance variable `rights` under property `properties` whose type is `AuthorizationRuleProperties`
  - Model `Cluster` moved instance variable `created_at`, `updated_at`, `metric_id`, `status` and `supports_scaling` under property `properties` whose type is `ClusterProperties`
  - Model `ConsumerGroup` moved instance variable `created_at`, `updated_at` and `user_metadata` under property `properties` whose type is `ConsumerGroupProperties`
  - Model `Destination` moved instance variable `storage_account_resource_id`, `blob_container`, `archive_name_format`, `data_lake_subscription_id`, `data_lake_account_name` and `data_lake_folder_path` under property `properties` whose type is `DestinationProperties`
  - Model `EHNamespace` moved instance variable `minimum_tls_version`, `provisioning_state`, `status`, `created_at`, `updated_at`, `service_bus_endpoint`, `cluster_arm_id`, `metric_id`, `is_auto_inflate_enabled`, `public_network_access`, `maximum_throughput_units`, `kafka_enabled`, `zone_redundant`, `encryption`, `private_endpoint_connections`, `disable_local_auth` and `alternate_name` under property `properties` whose type is `EHNamespaceProperties`
  - Model `Eventhub` moved instance variable `partition_ids`, `created_at`, `updated_at`, `message_retention_in_days`, `partition_count`, `status` and `capture_description` under property `properties` whose type is `EventhubProperties`
  - Model `NetworkRuleSet` moved instance variable `trusted_service_access_enabled`, `default_action`, `virtual_network_rules`, `ip_rules` and `public_network_access` under property `properties` whose type is `NetworkRuleSetProperties`
  - Model `NetworkSecurityPerimeterConfiguration` moved instance variable `provisioning_state`, `provisioning_issues`, `network_security_perimeter`, `resource_association` and `profile` under property `properties` whose type is `NetworkSecurityPerimeterConfigurationProperties`
  - Model `NetworkSecurityPerimeterConfiguration` deleted or renamed its instance variable `tags`
  - Model `PrivateEndpointConnection` moved instance variable `private_endpoint`, `private_link_service_connection_state` and `provisioning_state` under property `properties` whose type is `PrivateEndpointConnectionProperties`
  - Model `PrivateLinkResource` moved instance variable `group_id`, `required_members` and `required_zone_names` under property `properties` whose type is `PrivateLinkResourceProperties`
  - Model `ProxyResource` deleted or renamed its instance variable `location`
  - Model `SchemaGroup` moved instance variable `updated_at_utc`, `created_at_utc`, `e_tag`, `group_properties`, `schema_compatibility` and `schema_type` under property `properties` whose type is `SchemaGroupProperties`
  - Method `NetworkSecurityPerimeterConfigurationsOperations.begin_create_or_update` changed return type from `LROPoller[None]` to `LROPoller[NetworkSecurityPerimeterConfiguration]`

### Other Changes

  - Deleted model `ApplicationGroupListResult`/`ArmDisasterRecoveryListResult`/`AuthorizationRuleListResult`/`ClusterListResult`/`ConsumerGroupListResult`/`EHNamespaceListResult`/`EventHubListResult`/`OperationListResult`/`PrivateEndpointConnectionListResult`/`SchemaGroupListResult` which actually were not used by SDK users
  - Deleted model `TrackedResource` which actually were not used by SDK users

## 12.0.0b1 (2025-07-11)

### Features Added

  - Model `NetworkSecurityPerimeterConfiguration` added property `tags`

### Breaking Changes

  - This package now only targets the latest Api-Version available on Azure and removes APIs of other Api-Version. After this change, the package can have much smaller size. If your application requires a specific and non-latest Api-Version, it's recommended to pin this package to the previous released version; If your application always only use latest Api-Version, please ignore this change.
  - Model `Cluster` deleted or renamed its instance variable `provisioning_state`
  - Model `Destination` deleted or renamed its instance variable `identity`
  - Model `EHNamespace` deleted or renamed its instance variable `geo_data_replication`
  - Model `Eventhub` deleted or renamed its instance variable `retention_description`
  - Model `Eventhub` deleted or renamed its instance variable `message_timestamp_description`
  - Model `Eventhub` deleted or renamed its instance variable `identifier`
  - Model `Eventhub` deleted or renamed its instance variable `user_metadata`
  - Model `NetworkSecurityPerimeterConfiguration` deleted or renamed its instance variable `is_backing_resource`
  - Model `NetworkSecurityPerimeterConfiguration` deleted or renamed its instance variable `applicable_features`
  - Model `NetworkSecurityPerimeterConfiguration` deleted or renamed its instance variable `parent_association_name`
  - Model `NetworkSecurityPerimeterConfiguration` deleted or renamed its instance variable `source_resource_id`
  - Deleted or renamed enum value `SchemaType.JSON`
  - Deleted or renamed enum value `SchemaType.PROTO_BUF`
  - Deleted or renamed model `CaptureIdentity`
  - Deleted or renamed model `CaptureIdentityType`
  - Deleted or renamed model `CleanupPolicyRetentionDescription`
  - Deleted or renamed model `ErrorDetailAutoGenerated`
  - Deleted or renamed model `ErrorResponseAutoGenerated`
  - Deleted or renamed model `FailOver`
  - Deleted or renamed model `GeoDRRoleType`
  - Deleted or renamed model `GeoDataReplicationProperties`
  - Deleted or renamed model `MessageTimestampDescription`
  - Deleted or renamed model `NamespaceReplicaLocation`
  - Deleted or renamed model `ProvisioningState`
  - Deleted or renamed model `RetentionDescription`
  - Deleted or renamed model `TimestampType`
  - Deleted or renamed method `NamespacesOperations.begin_failover`

## 11.2.0 (2025-01-20)

### Features Added

  - Added operation NamespacesOperations.begin_failover
  - Model EHNamespace has a new parameter geo_data_replication
  - Model Eventhub has a new parameter identifier
  - Model Eventhub has a new parameter message_timestamp_description
  - Model RetentionDescription has a new parameter min_compaction_lag_in_mins

## 11.1.0 (2024-09-02)

### Features Added

  - Model Cluster has a new parameter provisioning_state
  - Model Destination has a new parameter identity
  - Model Eventhub has a new parameter user_metadata
  - Model NetworkSecurityPerimeterConfiguration has a new parameter applicable_features
  - Model NetworkSecurityPerimeterConfiguration has a new parameter is_backing_resource
  - Model NetworkSecurityPerimeterConfiguration has a new parameter location
  - Model NetworkSecurityPerimeterConfiguration has a new parameter parent_association_name
  - Model NetworkSecurityPerimeterConfiguration has a new parameter source_resource_id

## 11.0.0 (2023-04-14)

### Features Added

  - Model Eventhub has a new parameter retention_description

### Breaking Changes

  - Model NetworkSecurityPerimeterConfiguration no longer has parameter location
  - Model NetworkSecurityPerimeterConfiguration no longer has parameter tags

## 11.0.0b1 (2023-02-14)

### Features Added

  - Model Eventhub has a new parameter retention_description

### Breaking Changes

  - Model NetworkSecurityPerimeterConfiguration no longer has parameter location
  - Model NetworkSecurityPerimeterConfiguration no longer has parameter tags

## 10.1.0 (2022-06-22)

**Features**

  - Added operation group ApplicationGroupOperations
  - Added operation group NetworkSecurityPerimeterConfigurationOperations
  - Added operation group NetworkSecurityPerimeterConfigurationsOperations
  - Model Cluster has a new parameter supports_scaling
  - Model EHNamespace has a new parameter minimum_tls_version
  - Model EHNamespace has a new parameter public_network_access

## 10.0.0 (2021-11-01)

**Features**

  - Model ErrorResponse has a new parameter error
  - Model NetworkRuleSet has a new parameter location
  - Model Eventhub has a new parameter location
  - Model ConsumerGroup has a new parameter location
  - Model ArmDisasterRecovery has a new parameter location
  - Model Operation has a new parameter is_data_action
  - Model Operation has a new parameter origin
  - Model Operation has a new parameter properties
  - Model PrivateEndpointConnection has a new parameter location
  - Model Destination has a new parameter data_lake_account_name
  - Model Destination has a new parameter data_lake_subscription_id
  - Model Destination has a new parameter data_lake_folder_path
  - Model EHNamespace has a new parameter alternate_name
  - Model OperationDisplay has a new parameter description
  - Model AuthorizationRule has a new parameter location
  - Added operation NamespacesOperations.list_network_rule_set
  - Added operation group SchemaRegistryOperations

**Breaking changes**

  - Model ErrorResponse no longer has parameter message
  - Model ErrorResponse no longer has parameter code

## 9.1.0 (2021-09-17)

**Features**

  - Model Cluster has a new parameter system_data
  - Model EHNamespace has a new parameter disable_local_auth
  - Model EHNamespace has a new parameter status
  - Model NetworkRuleSet has a new parameter public_network_access
  - Added operation ClustersOperations.list_by_subscription

## 9.0.0 (2021-05-25)

**Features**

  - Model NetworkRuleSet has a new parameter system_data
  - Model ConsumerGroup has a new parameter system_data
  - Model PrivateEndpointConnection has a new parameter system_data
  - Model EHNamespace has a new parameter system_data
  - Model EHNamespace has a new parameter private_endpoint_connections
  - Model ArmDisasterRecovery has a new parameter system_data
  - Model Identity has a new parameter user_assigned_identities
  - Model Eventhub has a new parameter system_data
  - Model KeyVaultProperties has a new parameter identity
  - Model AuthorizationRule has a new parameter system_data
  - Model Encryption has a new parameter require_infrastructure_encryption

**Breaking changes**

  - Removed operation NamespacesOperations.list_ip_filter_rules
  - Removed operation NamespacesOperations.delete_virtual_network_rule
  - Removed operation NamespacesOperations.delete_ip_filter_rule
  - Removed operation NamespacesOperations.list_virtual_network_rules
  - Removed operation NamespacesOperations.create_or_update_virtual_network_rule
  - Removed operation NamespacesOperations.get_virtual_network_rule
  - Removed operation NamespacesOperations.create_or_update_ip_filter_rule
  - Removed operation NamespacesOperations.get_ip_filter_rule

## 8.0.0 (2020-09-16)

**Features**

  - Model NetworkRuleSet has a new parameter trusted_service_access_enabled
  - Added operation group PrivateEndpointConnectionsOperations
  - Added operation group PrivateLinkResourcesOperations

## 8.0.0b1 (2020-06-17)

This is beta preview version.

This version uses a next-generation code generator that introduces important breaking changes, but also important new features (like unified authentication and async programming).

**General breaking changes**

- Credential system has been completly revamped:

  - `azure.common.credentials` or `msrestazure.azure_active_directory` instances are no longer supported, use the `azure-identity` classes instead: https://pypi.org/project/azure-identity/
  - `credentials` parameter has been renamed `credential`

- The `config` attribute no longer exists on a client, configuration should be passed as kwarg. Example: `MyClient(credential, subscription_id, enable_logging=True)`. For a complete set of
  supported options, see the [parameters accept in init documentation of azure-core](https://github.com/Azure/azure-sdk-for-python/blob/main/sdk/core/azure-core/CLIENT_LIBRARY_DEVELOPER.md#available-policies)
- You can't import a `version` module anymore, use `__version__` instead
- Operations that used to return a `msrest.polling.LROPoller` now returns a `azure.core.polling.LROPoller` and are prefixed with `begin_`.
- Exceptions tree have been simplified and most exceptions are now `azure.core.exceptions.HttpResponseError` (`CloudError` has been removed).
- Most of the operation kwarg have changed. Some of the most noticeable:

  - `raw` has been removed. Equivalent feature can be found using `cls`, a callback that will give access to internal HTTP response for advanced user
  - For a complete set of
  supported options, see the [parameters accept in Request documentation of azure-core](https://github.com/Azure/azure-sdk-for-python/blob/main/sdk/core/azure-core/CLIENT_LIBRARY_DEVELOPER.md#available-policies)

**General new features**

- Type annotations support using `typing`. SDKs are mypy ready.
- This client has now stable and official support for async. Check the `aio` namespace of your package to find the async client.
- This client now support natively tracing library like OpenCensus or OpenTelemetry. See this [tracing quickstart](https://github.com/Azure/azure-sdk-for-python/tree/main/sdk/core/azure-core-tracing-opentelemetry) for an overview.

## 4.0.0 (2020-06-12)

**Features**

  - Model Cluster has a new parameter updated_at
  - Model Cluster has a new parameter created_at
  - Added operation ClustersOperations.update
  - Added operation ClustersOperations.create_or_update
  - Added operation ClustersOperations.list_available_cluster_region

** Breaking changes**

  - Model Cluster no longer has parameter created
  - Model Cluster no longer has parameter updated
  - Removed operation ClustersOperations.put
  - Removed operation ClustersOperations.list_available_clusters
  - Removed operation ClustersOperations.patch

## 3.1.0 (2020-05-13)

**Features**

  - Model EHNamespace has a new parameter encryption
  - Model EHNamespace has a new parameter identity
  - Model EHNamespace has a new parameter cluster_arm_id
  - Added operation NamespacesOperations.list_keys
  - Added operation NamespacesOperations.get_authorization_rule
  - Added operation NamespacesOperations.check_name_availability
  - Added operation NamespacesOperations.list_authorization_rules
  - Added operation NamespacesOperations.regenerate_keys
  - Added operation NamespacesOperations.create_or_update_authorization_rule
  - Added operation NamespacesOperations.delete_authorization_rule

## 3.0.0 (2019-06-18)

**General Breaking changes**

This version uses a next-generation code generator that *might*
introduce breaking changes if you were importing from the v20xx_yy_zz
API folders. In summary, some modules were incorrectly
visible/importable and have been renamed. This fixed several issues
caused by usage of classes that were not supposed to be used in the
first place.

  - EventHubManagementClient cannot be imported from
    `azure.mgmt.eventhub.v20xx_yy_zz.event_hub_management_client`
    anymore (import from `azure.mgmt.eventhub.v20xx_yy_zz` works
    like before)
  - EventHubManagementClientConfiguration import has been moved from
    `azure.mgmt.eventhub.v20xx_yy_zz.event_hub_management_client`
    to `azure.mgmt.eventhub.v20xx_yy_zz`
  - A model `MyClass` from a "models" sub-module cannot be imported
    anymore using `azure.mgmt.eventhub.v20xx_yy_zz.models.my_class`
    (import from `azure.mgmt.eventhub.v20xx_yy_zz.models` works like
    before)
  - An operation class `MyClassOperations` from an `operations`
    sub-module cannot be imported anymore using
    `azure.mgmt.eventhub.v20xx_yy_zz.operations.my_class_operations`
    (import from `azure.mgmt.eventhub.v20xx_yy_zz.operations` works
    like before)

Last but not least, HTTP connection pooling is now enabled by default.
You should always use a client as a context manager, or call close(), or
use no more than one client per process.

## 2.6.0 (2019-04-29)

**Preview features**

  - Added operation ClustersOperations.put
  - Added operation ClustersOperations.list_available_clusters
  - Added operation ClustersOperations.list_namespaces
  - Added operation ClustersOperations.delete

**Bugfixes**

  - Remove useless files packaged by mistake
    (azure.mgmt.eventhub.operations folder)

## 2.5.0 (2019-04-09)

**Features**

  - Added operation
    NamespacesOperations.create_or_update_network_rule_set for the
    2017-04-01 API version
  - Added operation NamespacesOperations.get_network_rule_set for the
    2017-04-01 API version

## 2.4.0 (2019-03-06)

**Features**

  - MultiApi support for 2015-08-01, 2017-04-01 and 2018-01-01-preview
  - 2017-04-01 is the default API version

## 2.3.0 (2019-02-04)

**Features**

  - Model CaptureDescription has a new parameter skip_empty_archives

## 2.2.0 (2018-10-29)

**Features**

  - Add kafka_enabled attribute

**Note**

  - azure-mgmt-nspkg is not installed anymore on Python 3 (PEP420-based
    namespace package)

## 2.1.0 (2018-07-31)

**Features**

  - Add pending_replication_operations_count support

**Bugfixes**

  - Fix some Python3 models

## 2.0.0 (2018-05-04)

**General Breaking changes**

This version uses a next-generation code generator that *might*
introduce breaking changes.

  - Model signatures now use only keyword-argument syntax. All
    positional arguments must be re-written as keyword-arguments. To
    keep auto-completion in most cases, models are now generated for
    Python 2 and Python 3. Python 3 uses the "*" syntax for
    keyword-only arguments.
  - Enum types now use the "str" mixin (class AzureEnum(str, Enum)) to
    improve the behavior when unrecognized enum values are encountered.
    While this is not a breaking change, the distinctions are important,
    and are documented here:
    <https://docs.python.org/3/library/enum.html#others> At a glance:
      - "is" should not be used at all.
      - "format" will return the string value, where "%s" string
        formatting will return `NameOfEnum.stringvalue`. Format syntax
        should be prefered.
  - New Long Running Operation:
      - Return type changes from
        `msrestazure.azure_operation.AzureOperationPoller` to
        `msrest.polling.LROPoller`. External API is the same.
      - Return type is now **always** a `msrest.polling.LROPoller`,
        regardless of the optional parameters used.
      - The behavior has changed when using `raw=True`. Instead of
        returning the initial call result as `ClientRawResponse`,
        without polling, now this returns an LROPoller. After polling,
        the final resource will be returned as a `ClientRawResponse`.
      - New `polling` parameter. The default behavior is
        `Polling=True` which will poll using ARM algorithm. When
        `Polling=False`, the response of the initial call will be
        returned without polling.
      - `polling` parameter accepts instances of subclasses of
        `msrest.polling.PollingMethod`.
      - `add_done_callback` will no longer raise if called after
        polling is finished, but will instead execute the callback right
        away.

**Features**

  - Client class can be used as a context manager to keep the underlying
    HTTP session open for performance
  - Add region operations group
  - Add skip/top to relevant operations
  - Add get_messaging_plan operation

**Bugfixes**

  - Compatibility of the sdist with wheel 0.31.0

## 1.2.0 (2017-12-12)

**Features**

  - Add alternate_name to some models (GEO DR pairing)
  - Add disaster_recovery_configs.check_name_availability
  - Add disaster_recovery_configs.list_authorization_rules
  - Add disaster_recovery_configs.get_authorization_rule
  - Add disaster_recovery_configs.list_keys

**Bugfixes**

  - "rights" is now required, as expected, for operations called
    create_or_update_authorization_rule
  - Fix message_retention_in_days validation rule
  - Fix partition_count validation rule

## 1.1.0 (2017-10-26)

**Features**

  - Add disaster_recovery_configs operation group
  - Add Geo DR

## 1.0.0 (2017-06-27)

  - New API Version 2017-04-01
  - Expect breaking changes, migrating from an unstable client

This wheel package is built with the azure wheel extension

## 0.2.0 (2016-10-27)

**Breaking changes**

  - CreateOrUpdate has flatten its parameters, moving from one big
    Properties object to several small specifics.

## 0.1.0 (2016-10-27)

  - Initial Release
